# Generated by ariadne-codegen on 2023-11-27 16:19
# Source: operations.graphql

from typing import List

from .base_model import BaseModel
from .fragments import EntitlementFragment


class GetEntitlements(BaseModel):
    entitlements: List["GetEntitlementsEntitlements"]


class GetEntitlementsEntitlements(EntitlementFragment):
    pass


GetEntitlements.update_forward_refs()
GetEntitlementsEntitlements.update_forward_refs()
